@@ -12,17 +12,17 @@ void StepperClass::elaborate( MethodDescriptor* m ) {
         if (strcmp(m->getName(),"new") == 0) {       
             int prm = 0;
             v.insert(new Stepper (m->getInt(prm++), m->getInt(prm++), m->getInt(prm++)));
-            Serial.println(v.getLastIndex());
+            m->returns(v.getLastIndex());
         }
 
         if (strcmp(m->getName(), "setSpeed") == 0) {
             v[m->getObjectId()]->setSpeed(m->getInt(0));
-            Serial.println("0");
+            m->returns("0");
         }
 
         if (strcmp(m->getName(), "step") == 0) {
             v[m->getObjectId()]->step(m->getInt(0));
-            Serial.println("0");
+            m->returns("0");
         }
 
     }
