@@ -1,5 +1,7 @@
 from nanpy.arduinoboard import (call_static_method, return_value)
-from nanpy.arduinoboard import (arduinoclassmethod, returnint)
+from nanpy.arduinoboard import (arduinoclassmethod, returns)
+
+import time
 
 class Arduino():
 
@@ -14,7 +16,7 @@ class Arduino():
         pass
 
     @classmethod
-    @returnint
+    @returns(int)
     @arduinoclassmethod
     def digitalRead(cls, pin):
         pass
@@ -25,7 +27,7 @@ class Arduino():
         pass
 
     @classmethod
-    @returnint
+    @returns(int)
     @arduinoclassmethod
     def analogRead(cls, pin):
         pass
@@ -38,5 +40,5 @@ class Arduino():
     @classmethod
     @arduinoclassmethod
     def delay(cls, value):
-        pass
+        time.sleep(value/1000)
 
