@@ -1,34 +1,46 @@
 from nanpy.arduinoboard import ArduinoObject
-from nanpy.arduinoboard import (arduinoobjectmethod, arduinoclassmethod, returnfloat, returnint)
+from nanpy.arduinoboard import (arduinoobjectmethod, arduinoclassmethod, returns)
 
 class DallasTemperature(ArduinoObject):
 
     def __init__(self, pin):
         ArduinoObject.__init__(self)
+        self.pin = pin
         self.id = self.call('new', pin)
 
+    @returns(int)
     @arduinoobjectmethod
-    def requestTemperatures(self):
+    def getDeviceCount(self):
         pass
 
-    @returnfloat
+    def getAddress(self, index):
+        val = self.call('getAddress')
+        if val == "1":
+            return val
+        return val.split(" ")
+
     @arduinoobjectmethod
-    def getTempCByIndex(self, index):
+    def requestTemperatures(self, address = None):
         pass
 
-    @returnfloat
+    @returns(float)
     @arduinoobjectmethod
-    def getTempFByIndex(self, index):
+    def getTempC(self, address):
+        pass
+
+    @returns(float)
+    @arduinoobjectmethod
+    def getTempF(self, address):
         pass
 
     @classmethod
-    @returnfloat
+    @returns(float)
     @arduinoclassmethod
     def toCelsius(cls, value):
         pass
 
     @classmethod
-    @returnfloat
+    @returns(float)
     @arduinoclassmethod
     def toFahrenheit(cls, value):
         pass
