@@ -1,13 +1,5 @@
 from nanpy.arduinoboard import ArduinoObject
-from nanpy.arduinoboard import (arduinoobjectmethod, returnint)
-
-class OneWireAddress():
-
-    def __init__(self, bytes):
-        self.__bytes = bytes
-
-    def get(self):
-        return self.__bytes
+from nanpy.arduinoboard import (arduinoobjectmethod, returns)
 
 class OneWire(ArduinoObject):
     
@@ -19,12 +11,13 @@ class OneWire(ArduinoObject):
         val = self.call('search')
         if val == "1":
             return val
-        return OneWireAddress(val.split(" "))
+        return val.split(" ")
 
+    @arduinoobjectmethod
     def select(self, address):
-        return self.call('select', address.get())
+        pass
 
-    @returnint
+    @returns(int)
     @arduinoobjectmethod
     def read(self):
         pass
